@@ -122,7 +122,7 @@ class Job(object):
         # The cost of `'lxml' in sys.modules' is negligible and is
         # preferable to having a hard dependency on lxml.
         from lxml import etree
-        return etree.fromstring(self.config)
+        return etree.fromstring(self.config.encode('utf8'))
 
     @config_etree.setter
     def config_etree(self, newconfig):
@@ -256,7 +256,7 @@ class View(object):
         # The cost of `'lxml' in sys.modules' is negligible and is
         # preferable to having a hard dependency on lxml.
         from lxml import etree
-        return etree.fromstring(self.config)
+        return etree.fromstring(self.config.encode('utf8'))
 
     @config_etree.setter
     def config_etree(self, newconfig):
@@ -316,6 +316,16 @@ class View(object):
             msg = 'could not add job "%s" to view "%s"'
             raise JenkinsError(msg % (job.name, self.name))
 
+    def has_job(self, job):
+        '''Check if view contains job.'''
+        config = self.config_etree
+        jobs = config.xpath('jobNames/string/text()')
+        job = getattr(job, 'name', job)
+        return job in jobs
+
+    def __contains__(self, job):
+        return self.has_job(job)
+
     @classmethod
     def create(cls, name, configxml, server):
         '''Create a new Jenkins view.'''
@@ -336,7 +346,7 @@ class View(object):
 
 #-----------------------------------------------------------------------------
 class Build(object):
-    '''A representation of a Jenkins build.'''
+    '''Represents a Jenkins build.'''
 
     __slots__ = 'job', 'number'
 
@@ -362,11 +372,11 @@ class Build(object):
         url = 'job/%s/%d/stop' % (self.job.name, self.number)
         return self.job.server.post(url)
 
-    def wait(self, interval=1, timeout=None):
+    def wait(self, tick=1, timeout=None):
         '''Wait for build to complete.'''
         start = time.time()
         while self.building:
-            time.sleep(interval)
+            time.sleep(tick)
             if timeout and (time.time() - start) > timeout:
                 break
 
@@ -501,6 +511,19 @@ class Jenkins(object):
     def job_copy(self, source, dest):
         return Job.copy(source, dest, self.server)
 
+    #-------------------------------------------------------------------------
+    def build_info(self, job, number):
+        return self.build(job, number).info
+
+    def build_isbuilding(self, job, number):
+        return self.build(job, number).building
+
+    def build_stop(self, job, number):
+        return self.build(job, number).stop()
+
+    def build_wait(self, job, number, interval=1, timeout=None):
+        return self.build(job, number).wait()
+
     #-------------------------------------------------------------------------
     def view_exists(self, name):
         return self.view(name).exists
@@ -528,6 +551,10 @@ class Jenkins(object):
         job = self.job(job_name)
         return self.view(name).add_job(job)
 
+    def view_has_job(self, name, job_name):
+        job = self.job(job_name)
+        return self.view(name).has_job(job)
+
     def view_remove_job(self, name, job_name):
         job = self.job(job_name)
         return self.view(name).remove_job(job)
@@ -544,11 +571,15 @@ class Jenkins(object):
     job_create.__doc__ = Job.create.__doc__
     job_copy.__doc__ = Job.copy.__doc__
 
+    build_stop.__doc__ = Build.stop.__doc__
+    build_wait.__doc__ = Build.wait.__doc__
+
     view_exists.__doc__ = View.exists.__doc__
     view_add_job.__doc__ = View.add_job.__doc__
     view_remove_job.__doc__ = View.remove_job.__doc__
     view_create.__doc__ = View.create.__doc__
     view_delete.__doc__ = View.delete.__doc__
+    view_has_job.__doc__ = View.has_job.__doc__
 
 
 #-----------------------------------------------------------------------------
